==> dumux-3.8.0-2-x86_64.pkg.tar.zst: usr/share/doc/dumux/doxygen/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "DuMux", "index.html", [
    [ "Introduction", "index.html", "index" ],
    [ "Installation", "installation.html", null ],
    [ "Getting started", "getting-started.html", null ],
    [ "External libraries", "external-libraries.html", null ],
    [ "Examples and tutorials", "examples-and-tutorials.html", null ],
    [ "Usage documentation", "usage-documentation.html", [
      [ "Runtime parameters", "runtime-parameters.html", null ],
      [ "Running in parallel", "running-in-parallel.html", null ],
      [ "Input and output formats", "input-and-output-formats.html", null ],
      [ "Directory structure", "directory-structure.html", null ]
    ] ],
    [ "Flow and transport in porous media", "flow-and-transport-in-porous-media.html", null ],
    [ "Basic numerics", "basic-numerics.html", null ],
    [ "Python bindings", "python-bindings.html", null ],
    [ "Developer documentation", "usergroup0.html", [
      [ "Dumux and Dune", "dumux-and-dune.html", null ],
      [ "Developing Dumux", "developing-dumux.html", null ],
      [ "Build doxygen documentation", "building-the-documentation.html", null ]
    ] ],
    [ "Bibliography", "citelist.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", "functions_type" ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_dumux_1_1_box_f_v_element_geometry_3_01_g_g_00_01true_01_4.html#a972fd44ad50424f4f1d7c83fab03e7fc",
"class_dumux_1_1_c_v_f_e_grid_volume_variables_3_01_traits_00_01true_01_4.html#a278b9bdaff54eee8ceda6bf2fdddad53",
"class_dumux_1_1_detail_1_1_old_istl_solver_factory_backend.html#a22842e7ad41ee74170dd206f69c3fe34",
"class_dumux_1_1_experimental_1_1_multi_stage_1_1_runge_kutta_explicit_fourth_order.html#afbba258d0ea29a2d8476d7cdfea6fafb",
"class_dumux_1_1_k_omega_flux_variables_impl_3_01_type_tag_00_01_base_flux_variables_00_01_discre89954a90f06c275cf3d86b15437c72de.html#abf84967cf51df8d36dde93b0100a0469",
"class_dumux_1_1_navier_stokes_flux_variables_impl_3_01_type_tag_00_01_discretization_methods_1_1_staggered_01_4.html#a597335fe2afb5760fe2e7d929c3422d3",
"class_dumux_1_1_navier_stokes_momentum_problem_impl_3_01_type_tag_00_01_discretization_methods_1_1_f_c_staggered_01_4.html#a6fd624eca3567053119e8d55b6d79d7b",
"class_dumux_1_1_non_equilibrium_volume_variables_implementation_3_01_traits_00_01_equilibrium_vob45765f9be228cb8e971fd44958cc131.html#a192d4e4b5bccb2bfdd32296a35e1ba3d",
"class_dumux_1_1_pore_network_1_1_p_n_m_f_v_element_geometry_3_01_g_g_00_01false_01_4.html#a48043c266ff0fdf114c4574b02c2365c",
"class_dumux_1_1_s_s_t_residual_impl_3_01_type_tag_00_01_base_local_residual_00_01_discretization_methods_1_1_staggered_01_4.html#aa773ce6ad561bef2bb7233b53b452b3d",
"functions_vars_b.html",
"namespace_dumux_1_1_discretization_methods.html#a6ff92a9c03abff3f0f31483c543609a8",
"struct_dumux_1_1_advective_flux_3_01_navier_stokes_energy_model_traits_3_01_navier_stokes_mass_oab18b42b49771b8a936a5c6e6a71fc4d.html#a219c74bd2757ecdad0ccb1e61c0cc20d",
"struct_dumux_1_1_detail_1_1_f_c_diamond_1_1_scv_corners_3_01_dune_1_1_geometry_types_1_1hexahedron_01_4.html#ae01e6e450d57260871a6cbf081ff8943",
"struct_dumux_1_1_detail_1_1_momentum_discretization_method.html#a0f123490c4216436a28e5c2d50ebd693",
"struct_dumux_1_1_detail_1_1_staggered_1_1_sub_domain_jacobian_matrix_impl.html",
"struct_dumux_1_1_free_flow_pore_network_detail_1_1_coupling_maps.html#abc870121a24293c3dff52a3de008ef79",
"struct_dumux_1_1_linear_solver_traits_impl_3_01_grid_geometry_00_01_discretization_methods_1_1_f_c_staggered_01_4.html#a77354dbe161a43b6207de44c005a9c3c",
"struct_dumux_1_1_properties_1_1_advection_type_3_01_type_tag_00_01_t_tag_1_1_p_n_m_one_p_01_4.html#a22cf88ed747653140e5100dd2f1d42e3",
"struct_dumux_1_1_properties_1_1_enable_grid_volume_variables_cache_3_01_type_tag_00_01_dumux_1_121de689e53a6be849a62b8901eceb65b.html",
"struct_dumux_1_1_properties_1_1_flux_variables_3_01_type_tag_00_01_t_tag_1_1_navier_stokes_mass_one_p_n_c_01_4.html#af0b4206cbbc8a974002e3bdeac46d1c1",
"struct_dumux_1_1_properties_1_1_grid_variables_3_01_type_tag_00_01_t_tag_1_1_face_centered_staggered_model_01_4.html#ae3a9bed07676f1c28908ef9e1f457648",
"struct_dumux_1_1_properties_1_1_i_o_fields_3_01_type_tag_00_01_t_tag_1_1_p_n_m_two_p_01_4.html#a41745203b6c9e3053a1a44d2b1b7b3f0",
"struct_dumux_1_1_properties_1_1_local_residual_3_01_type_tag_00_01_t_tag_1_1_one_eq_n_c_n_i_01_4.html#afb7ee06f19145025bb2d41718041cf71",
"struct_dumux_1_1_properties_1_1_model_traits_3_01_type_tag_00_01_t_tag_1_1_one_p_n_i_01_4.html",
"struct_dumux_1_1_properties_1_1_primary_variables_3_01_type_tag_00_01_t_tag_1_1_three_p_water_oil_n_i_01_4.html#a9e8c2f8429b769137a63a0697e3c6d0c",
"struct_dumux_1_1_properties_1_1_t_tag_1_1_grid_properties.html",
"struct_dumux_1_1_properties_1_1_t_tag_1_1_staggered_model.html",
"struct_dumux_1_1_properties_1_1_use_moles_3_01_type_tag_00_01_t_tag_1_1_three_p_water_oil_n_i_01_4.html#a5f62ab3d1dbe9dcc4f300b793e1d9e9a",
"struct_dumux_1_1_properties_1_1_volume_variables_3_01_type_tag_00_01_t_tag_1_1_s_s_t_01_4.html#a5a5c81d767716858e37705771c909f39",
"struct_dumux_1_1_shallow_water_1_1_riemann_solution.html#a8a84e6f984e1a5d43980d8c831966362"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> dumux-3.8.0-3-x86_64.pkg.tar.zst: usr/share/doc/dumux/doxygen/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "DuMux", "index.html", [
    [ "Introduction", "index.html", "index" ],
    [ "Installation", "installation.html", null ],
    [ "Getting started", "getting-started.html", null ],
    [ "External libraries", "external-libraries.html", null ],
    [ "Examples and tutorials", "examples-and-tutorials.html", null ],
    [ "Usage documentation", "usage-documentation.html", [
      [ "Runtime parameters", "runtime-parameters.html", null ],
      [ "Running in parallel", "running-in-parallel.html", null ],
      [ "Input and output formats", "input-and-output-formats.html", null ],
      [ "Directory structure", "directory-structure.html", null ]
    ] ],
    [ "Flow and transport in porous media", "flow-and-transport-in-porous-media.html", null ],
    [ "Basic numerics", "basic-numerics.html", null ],
    [ "Python bindings", "python-bindings.html", null ],
    [ "Developer documentation", "usergroup0.html", [
      [ "Dumux and Dune", "dumux-and-dune.html", null ],
      [ "Developing Dumux", "developing-dumux.html", null ],
      [ "Build doxygen documentation", "building-the-documentation.html", null ]
    ] ],
    [ "Bibliography", "citelist.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", "functions_type" ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_dumux_1_1_box_f_v_element_geometry_3_01_g_g_00_01true_01_4.html#a972fd44ad50424f4f1d7c83fab03e7fc",
"class_dumux_1_1_c_v_f_e_grid_volume_variables_3_01_traits_00_01true_01_4.html#a278b9bdaff54eee8ceda6bf2fdddad53",
"class_dumux_1_1_detail_1_1_old_istl_solver_factory_backend.html#a22842e7ad41ee74170dd206f69c3fe34",
"class_dumux_1_1_experimental_1_1_multi_stage_1_1_runge_kutta_explicit_fourth_order.html#afbba258d0ea29a2d8476d7cdfea6fafb",
"class_dumux_1_1_k_omega_flux_variables_impl_3_01_type_tag_00_01_base_flux_variables_00_01_discre89954a90f06c275cf3d86b15437c72de.html#abf84967cf51df8d36dde93b0100a0469",
"class_dumux_1_1_navier_stokes_flux_variables_impl_3_01_type_tag_00_01_discretization_methods_1_1_staggered_01_4.html#a597335fe2afb5760fe2e7d929c3422d3",
"class_dumux_1_1_navier_stokes_momentum_problem_impl_3_01_type_tag_00_01_discretization_methods_1_1_f_c_staggered_01_4.html#a6fd624eca3567053119e8d55b6d79d7b",
"class_dumux_1_1_non_equilibrium_volume_variables_implementation_3_01_traits_00_01_equilibrium_vob45765f9be228cb8e971fd44958cc131.html#a192d4e4b5bccb2bfdd32296a35e1ba3d",
"class_dumux_1_1_pore_network_1_1_p_n_m_f_v_element_geometry_3_01_g_g_00_01false_01_4.html#a1dd66f58f263726008e71a928192453e",
"class_dumux_1_1_s_s_t_flux_variables_impl_3_01_type_tag_00_01_base_flux_variables_00_01_discreti322302480fab37f2573f620f7feb4a63.html#a44331a16931b03547156f5a391e8803d",
"functions_type_t.html",
"namespace_dumux_1_1_detail_1_1_preconditioners.html",
"namespacemembers_l.html",
"struct_dumux_1_1_detail_1_1_f_c_diamond_1_1_inside_outside_scv_3_01_index_type_00_01_dune_1_1_ge2a15d08fe053e99899fce32d2385b6a3.html#a9dddb53610090eacffcd862a38331330",
"struct_dumux_1_1_detail_1_1_local_dof_traits_3_01_grid_view_00_01_discretization_methods_1_1_f_c_diamond_01_4.html#a1677ff77056c569e0d3bcd2891a27a77",
"struct_dumux_1_1_detail_1_1_staggered_1_1_sub_domain_f_v_grid_geometry_impl_3_01_sub_domain_type_tag_00_010_01_4.html",
"struct_dumux_1_1_flux_variables_caching_1_1_empty_heat_conduction_cache.html",
"struct_dumux_1_1_linear_solver_traits_impl_3_01_grid_geometry_00_01_discretization_methods_1_1_f_c_diamond_01_4.html#a0faff0fc12b1d7de71df8560ee720d3a",
"struct_dumux_1_1_pore_network_1_1_fluid_matrix_1_1_platonic_body_params.html#ac0d3f277daf585e53cf1cb541e2c372f",
"struct_dumux_1_1_properties_1_1_element_boundary_types_3_01_type_tag_00_01_t_tag_1_1_face_centered_staggered_model_01_4.html#a0ed42eab684e93dc4d29c654c58e5137",
"struct_dumux_1_1_properties_1_1_flux_variables_3_01_type_tag_00_01_t_tag_1_1_k_omega_01_4.html",
"struct_dumux_1_1_properties_1_1_grid_geometry_3_01_type_tag_00_01_t_tag_1_1_box_dfm_model_01_4.html",
"struct_dumux_1_1_properties_1_1_i_o_fields_3_01_type_tag_00_01_t_tag_1_1_one_p_01_4.html#a102b90cc0ae922a9593d78b1af06ab4c",
"struct_dumux_1_1_properties_1_1_local_residual_3_01_type_tag_00_01_t_tag_1_1_low_re_k_epsilon_n_c_n_i_01_4.html",
"struct_dumux_1_1_properties_1_1_model_traits_3_01_type_tag_00_01_t_tag_1_1_navier_stokes_n_i_01_4.html#a319048ddbf6299d675b645c77b106ef9",
"struct_dumux_1_1_properties_1_1_nusselt_formulation_3_01_type_tag_00_01_t_tag_1_1_non_equilibrium_01_4.html",
"struct_dumux_1_1_properties_1_1_t_tag_1_1_c_c_mpfa_facet_coupling_model.html#afce0ea9bf0a3c223003871fea4a2398f",
"struct_dumux_1_1_properties_1_1_t_tag_1_1_r_a_n_s_n_i.html#af05194879bf9bbbc9d8deae41cee5dd1",
"struct_dumux_1_1_properties_1_1_upwind_scheme_order_3_01_type_tag_00_01_t_tag_1_1_staggered_free_flow_model_01_4.html",
"struct_dumux_1_1_properties_1_1_volume_variables_3_01_type_tag_00_01_t_tag_1_1_p_n_m_one_p_n_c_01_4.html",
"struct_dumux_1_1_python_1_1_detail_1_1_solid_density.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
